@@ -48,9 +48,15 @@ describe('global methods', function () {
             expect(parseInt('  42')).toBe(parseInt('42', 10));
             expect(parseInt('  08')).toBe(parseInt('08', 10));
 
-            var ws = '\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003'
-                + '\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028'
-                + '\u2029\uFEFF';
+            var mvsIsWS = (/\s/).test('\u180E');
+            if (mvsIsWS) {
+                expect(parseInt('\u180E' + 1)).toBe(1);
+            } else {
+                expect(parseInt('\u180E' + 1)).toBeNaN();
+            }
+
+            var ws = '\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF'
+                .replace(/\S/g, ''); // remove the mongolian vowel separator (/u180E) on modern engines
             expect(parseInt(ws + '08')).toBe(parseInt('08', 10));
             expect(parseInt(ws + '0x16')).toBe(parseInt('0x16', 16));
         });
